from unittest.mock import patch
from unittest.mock import MagicMock

from gatox.attack.runner.webshell import WebShell


def test_ror_workflow():

    workflow = WebShell.create_ror_workflow(
        "foobar",
        "evil",
        "https://example.com",
        runner_labels=["self-hosted", "super-secure"],
    )

    assert "continue-on-error: true" in workflow



from gatox.attack.cicd_attack import CICDAttack
from gatox.attack.payloads.payloads import Payloads


def test_create_malicious_push_yaml():
    """Test code to create a malicious yaml file"""
    yaml = CICDAttack.create_push_yml("whoami", "testing")

    assert "run: whoami" in yaml
